==> relations-0.0.0-src.tar.gz: relations/src/net/morilib/db/misc/ErrorBundle.java <==
/*
 * Copyright 2009-2010 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.db.misc;

import java.sql.SQLException;
import java.util.Locale;
import java.util.ResourceBundle;

/**
 *
 *
 * @author MORIGUCHI, Yuichiro 2013/08/11
 */
public final class ErrorBundle {

	private static final ErrorBundle _DEF = getInstance(
			Locale.getDefault());

	private ResourceBundle bundle;

	private ErrorBundle(ResourceBundle b) {
		bundle = b;
	}

	/**
	 * 
	 * @return
	 */
	public synchronized static ErrorBundle getInstance(Locale locale) {
		ResourceBundle b;

		b = ResourceBundle.getBundle(
				"net/morilib/db/misc/relations_errors",
				locale);
		return new ErrorBundle(b);
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public SQLException getException(int code, Object... mesg) {
		String s = bundle.getString(code + "");

		if(s != null) {
			s = String.format(s, mesg);
			return new SQLException(s, null, code);
		} else {
			return new SQLException(
					"unknown code: " + code,
					null,
					99999);
		}
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public static SQLException getDefault(int code, Object... mesg) {
		return _DEF.getException(code, mesg);
	}

}

==> relations-0.0.1-src.tar.gz: relations/src/net/morilib/db/misc/ErrorBundle.java <==
/*
 * Copyright 2009-2010 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.db.misc;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.sql.SQLException;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.logging.Logger;

import net.morilib.db.jdbc.RelationsJDBCUtils;

/**
 *
 *
 * @author MORIGUCHI, Yuichiro 2013/08/11
 */
public final class ErrorBundle {

	private static Logger logger = RelationsJDBCUtils.logger;
	private static final ErrorBundle _DEF = getInstance(
			Locale.getDefault());

	private ResourceBundle bundle;

	private ErrorBundle(ResourceBundle b) {
		bundle = b;
	}

	/**
	 * 
	 * @return
	 */
	public synchronized static ErrorBundle getInstance(Locale locale) {
		ResourceBundle b;

		b = ResourceBundle.getBundle(
				"net/morilib/db/misc/relations_errors",
				locale);
		return new ErrorBundle(b);
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public SQLException getException(int code, Object... mesg) {
		String s = bundle.getString(code + "");
		StringWriter t = new StringWriter();
		PrintWriter w = new PrintWriter(t);
		SQLException e;

		if(s != null) {
			s = String.format(s, mesg);
			e = new SQLException(s, null, code);
		} else {
			e = new SQLException(
					"unknown code: " + code,
					null,
					99999);
		}
		e.printStackTrace(w);
		w.flush();
		logger.finer(w.toString());
		return e;
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public SQLException getIOException(Throwable z, Object... mesg) {
		String s = bundle.getString("10037");
		StringWriter t = new StringWriter();
		PrintWriter w = new PrintWriter(t);
		SQLException e;

		s = String.format(s, mesg);
		e = new SQLException(s, null, 10037, z);
		e.printStackTrace(w);
		w.flush();
		logger.finer(t.toString());
		return e;
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public static SQLException getDefault(int code, Object... mesg) {
		return _DEF.getException(code, mesg);
	}

	/**
	 * 
	 * @param code
	 * @return
	 */
	public static SQLException getIODefault(Throwable z,
			Object... mesg) {
		return _DEF.getIOException(z, mesg);
	}

}
